// This file has been auto-generated.  Do not hand-edit this.

const char* token_names[] = {
    "??", // 0
    "AllowBlank", // 1
    "AnswerR", // 2
    "Area", // 3
    "ArrowShapeA", // 4
    "ArrowShapeB", // 5
    "ArrowShapeC", // 6
    "Attribute", // 7
    "Attributes", // 8
    "Author", // 9
    "AutoScale", // 10
    "Back", // 11
    "Bold", // 12
    "Bottom", // 13
    "Calculation", // 14
    "Cell", // 15
    "CellComment", // 16
    "Cells", // 17
    "CellsStr", // 18
    "Col", // 19
    "ColInfo", // 20
    "Collapsed", // 21
    "Color", // 22
    "Cols", // 23
    "Comment", // 24
    "Condition", // 25
    "Constr", // 26
    "Content", // 27
    "Count", // 28
    "CursorCol", // 29
    "CursorRow", // 30
    "DateConvention", // 31
    "DefaultSizePts", // 32
    "Diagonal", // 33
    "Direction", // 34
    "Discr", // 35
    "DisplayFormulas", // 36
    "DisplayOutlines", // 37
    "EnableIteration", // 38
    "Epoch", // 39
    "ExprConvention", // 40
    "ExprID", // 41
    "Expression0", // 42
    "Expression1", // 43
    "Field", // 44
    "FillColor", // 45
    "Filter", // 46
    "Filters", // 47
    "FloatDigits", // 48
    "FloatRadix", // 49
    "Font", // 50
    "Footer", // 51
    "Fore", // 52
    "Format", // 53
    "FreezePanes", // 54
    "FrozenTopLeft", // 55
    "Full", // 56
    "Geometry", // 57
    "GogObject", // 58
    "GridColor", // 59
    "HAlign", // 60
    "HardSize", // 61
    "Header", // 62
    "Height", // 63
    "Hidden", // 64
    "HideColHeader", // 65
    "HideGrid", // 66
    "HideRowHeader", // 67
    "HideZero", // 68
    "HyperLink", // 69
    "Inc", // 70
    "Indent", // 71
    "Index", // 72
    "Input", // 73
    "InputMessage", // 74
    "Inputs", // 75
    "Italic", // 76
    "IterationTolerance", // 77
    "Label", // 78
    "LabelFormat", // 79
    "Lcol", // 80
    "Left", // 81
    "LimitsR", // 82
    "Locked", // 83
    "Lrow", // 84
    "Major", // 85
    "ManualRecalc", // 86
    "MarginA", // 87
    "MarginB", // 88
    "Margins", // 89
    "Max", // 90
    "MaxCol", // 91
    "MaxIter", // 92
    "MaxIterations", // 93
    "MaxRow", // 94
    "MaxTime", // 95
    "Merge", // 96
    "MergedRegions", // 97
    "Message", // 98
    "Middle", // 99
    "Min", // 100
    "Minor", // 101
    "ModelType", // 102
    "Name", // 103
    "Names", // 104
    "No", // 105
    "NonNeg", // 106
    "ObjectAnchorType", // 107
    "ObjectBound", // 108
    "ObjectOffset", // 109
    "Objects", // 110
    "Op0", // 111
    "Op1", // 112
    "Operator", // 113
    "Orient", // 114
    "OutlineColor", // 115
    "OutlineLevel", // 116
    "OutlineSymbolsBelow", // 117
    "OutlineSymbolsRight", // 118
    "Output", // 119
    "Page", // 120
    "PatternColor", // 121
    "PerformR", // 122
    "Points", // 123
    "PrefUnit", // 124
    "Print", // 125
    "PrintInformation", // 126
    "ProblemType", // 127
    "ProgramR", // 128
    "Protected", // 129
    "RTL_Layout", // 130
    "Rcol", // 131
    "Rev-Diagonal", // 132
    "Right", // 133
    "Rotation", // 134
    "Row", // 135
    "RowInfo", // 136
    "Rows", // 137
    "Rrow", // 138
    "Scale", // 139
    "Scenario", // 140
    "Scenarios", // 141
    "Script", // 142
    "SelectedTab", // 143
    "Selection", // 144
    "Selections", // 145
    "SensitivityR", // 146
    "Shade", // 147
    "Sheet", // 148
    "SheetLayout", // 149
    "SheetName", // 150
    "SheetNameIndex", // 151
    "SheetObjectBonobo", // 152
    "SheetObjectFilled", // 153
    "SheetObjectGraph", // 154
    "SheetObjectImage", // 155
    "SheetWidgetButton", // 156
    "SheetWidgetCheckbox", // 157
    "SheetWidgetCombo", // 158
    "SheetWidgetFrame", // 159
    "SheetWidgetLabel", // 160
    "SheetWidgetList", // 161
    "SheetWidgetScrollbar", // 162
    "SheetWidgetSlider", // 163
    "SheetWidgetSpinbutton", // 164
    "SheetWidgetToggleButton", // 165
    "Sheets", // 166
    "ShowIter", // 167
    "ShrinkToFit", // 168
    "Solver", // 169
    "StrikeThrough", // 170
    "Style", // 171
    "StyleBorder", // 172
    "StyleRegion", // 173
    "Styles", // 174
    "TabColor", // 175
    "TabTextColor", // 176
    "TargetCol", // 177
    "TargetRow", // 178
    "Text", // 179
    "TextFormat", // 180
    "Title", // 181
    "Top", // 182
    "TopLeft", // 183
    "Type", // 184
    "UIData", // 185
    "Underline", // 186
    "UnfrozenTopLeft", // 187
    "Unit", // 188
    "UseDropdown", // 189
    "VAlign", // 190
    "Validation", // 191
    "Value", // 192
    "Value0", // 193
    "Value1", // 194
    "ValueFormat", // 195
    "ValueType", // 196
    "ValueType0", // 197
    "ValueType1", // 198
    "Version", // 199
    "Visibility", // 200
    "Width", // 201
    "Workbook", // 202
    "WrapText", // 203
    "Zoom", // 204
    "bottom", // 205
    "break", // 206
    "cols", // 207
    "count", // 208
    "crop-bottom", // 209
    "crop-left", // 210
    "crop-right", // 211
    "crop-top", // 212
    "data", // 213
    "dimension", // 214
    "do_not_print", // 215
    "draft", // 216
    "endCol", // 217
    "endRow", // 218
    "even_if_only_styles", // 219
    "footer", // 220
    "grid", // 221
    "hPageBreaks", // 222
    "hcenter", // 223
    "header", // 224
    "id", // 225
    "image-type", // 226
    "items", // 227
    "left", // 228
    "monochrome", // 229
    "name", // 230
    "order", // 231
    "orientation", // 232
    "paper", // 233
    "percentage", // 234
    "pos", // 235
    "position", // 236
    "print-to-uri", // 237
    "print_range", // 238
    "property", // 239
    "repeat_left", // 240
    "repeat_top", // 241
    "right", // 242
    "role", // 243
    "rows", // 244
    "size-bytes", // 245
    "startCol", // 246
    "startRow", // 247
    "target", // 248
    "tip", // 249
    "titles", // 250
    "top", // 251
    "type", // 252
    "vPageBreaks", // 253
    "value", // 254
    "vcenter"  // 255
};

size_t token_name_count = 256;

