namespace orcus {

extern const xmlns_id_t NS_odf_anim;
extern const xmlns_id_t NS_odf_chart;
extern const xmlns_id_t NS_odf_config;
extern const xmlns_id_t NS_odf_db;
extern const xmlns_id_t NS_odf_dc;
extern const xmlns_id_t NS_odf_dr3d;
extern const xmlns_id_t NS_odf_draw;
extern const xmlns_id_t NS_odf_fo;
extern const xmlns_id_t NS_odf_form;
extern const xmlns_id_t NS_odf_grddl;
extern const xmlns_id_t NS_odf_math;
extern const xmlns_id_t NS_odf_meta;
extern const xmlns_id_t NS_odf_number;
extern const xmlns_id_t NS_odf_office;
extern const xmlns_id_t NS_odf_presentation;
extern const xmlns_id_t NS_odf_script;
extern const xmlns_id_t NS_odf_smil;
extern const xmlns_id_t NS_odf_style;
extern const xmlns_id_t NS_odf_svg;
extern const xmlns_id_t NS_odf_table;
extern const xmlns_id_t NS_odf_text;
extern const xmlns_id_t NS_odf_xforms;
extern const xmlns_id_t NS_odf_xhtml;
extern const xmlns_id_t NS_odf_xlink;

extern const xmlns_id_t* NS_odf_all;

}

