/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */

#ifndef ORCUS_XLS_XML_NAMESPACE_TYPES_HPP
#define ORCUS_XLS_XML_NAMESPACE_TYPES_HPP

#include "orcus/types.hpp"

namespace orcus {

extern const xmlns_id_t NS_xls_xml_ss;
extern const xmlns_id_t NS_xls_xml_o;
extern const xmlns_id_t NS_xls_xml_x;
extern const xmlns_id_t NS_xls_xml_html;

/**
 * Null-terminated array of all xls xml namespaces.
 */
extern const xmlns_id_t* NS_xls_xml_all;

}

#endif
/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
