// This file has been auto-generated.  Do not hand-edit this.

const xml_token_t XML_ContentType = 1;
const xml_token_t XML_Default = 2;
const xml_token_t XML_Extension = 3;
const xml_token_t XML_Format = 4;
const xml_token_t XML_Id = 5;
const xml_token_t XML_Override = 6;
const xml_token_t XML_PartName = 7;
const xml_token_t XML_Relationship = 8;
const xml_token_t XML_RelationshipReference = 9;
const xml_token_t XML_Relationships = 10;
const xml_token_t XML_RelationshipsGroupReference = 11;
const xml_token_t XML_SignatureTime = 12;
const xml_token_t XML_SourceId = 13;
const xml_token_t XML_SourceType = 14;
const xml_token_t XML_Target = 15;
const xml_token_t XML_TargetMode = 16;
const xml_token_t XML_Type = 17;
const xml_token_t XML_Types = 18;
const xml_token_t XML_Value = 19;
const xml_token_t XML_category = 20;
const xml_token_t XML_contentStatus = 21;
const xml_token_t XML_contentType = 22;
const xml_token_t XML_coreProperties = 23;
const xml_token_t XML_keywords = 24;
const xml_token_t XML_lastModifiedBy = 25;
const xml_token_t XML_lastPrinted = 26;
const xml_token_t XML_revision = 27;
const xml_token_t XML_version = 28;

